@@ -127,7 +127,7 @@ func main() {
 		}
 		os.Exit(rc)
 	}
-	log.SetFlags(0)
+	log.SetFlags(log.Lshortfile)
 
 	var err error
 	Cwd, err = os.Getwd()
@@ -199,31 +199,31 @@ func main() {
 	// Those are internal envs
 	FdOODTgts, err = ioutil.TempFile("", "ood-tgts")
 	if err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 	if err = os.Remove(FdOODTgts.Name()); err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 	FdOODTgtsLock, err = ioutil.TempFile("", "ood-tgts.lock")
 	if err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 	if err = os.Remove(FdOODTgtsLock.Name()); err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 
 	if v := os.Getenv(EnvOODTgtsFd); v != "" {
 		fd := mustParseFd(v, EnvOODTgtsFd)
 		fdLock := mustParseFd(v, EnvOODTgtsLockFd)
 		if err = unix.Flock(int(fdLock.Fd()), unix.LOCK_EX); err != nil {
-			panic(err)
+			log.Fatalln(err)
 		}
 		if _, err = fd.Seek(0, io.SeekStart); err != nil {
-			panic(err)
+			log.Fatalln(err)
 		}
 		tgtsRaw, err := ioutil.ReadAll(bufio.NewReader(fd))
 		if err != nil {
-			panic(err)
+			log.Fatalln(err)
 		}
 		unix.Flock(int(fdLock.Fd()), unix.LOCK_UN)
 		OODTgts = map[string]struct{}{}
