@@ -23,6 +23,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"log"
 	"os"
 	"path"
 	"path/filepath"
@@ -223,13 +224,13 @@ func isOODWithTrace(
 	}
 RecordOODTgt:
 	if err = unix.Flock(int(FdOODTgtsLock.Fd()), unix.LOCK_EX); err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 	if _, err = FdOODTgts.Seek(0, io.SeekEnd); err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 	if _, err := FdOODTgts.WriteString(p + "\x00"); err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 	unix.Flock(int(FdOODTgtsLock.Fd()), unix.LOCK_UN)
 	return true, nil
@@ -237,10 +238,10 @@ RecordOODTgt:
 
 func oodTgtsClear() {
 	if err := unix.Flock(int(FdOODTgtsLock.Fd()), unix.LOCK_EX); err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 	if err := FdOODTgts.Truncate(0); err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 	unix.Flock(int(FdOODTgtsLock.Fd()), unix.LOCK_UN)
 }
