@@ -52,11 +52,12 @@ const (
 	EnvStderrSilent = "REDO_SILENT"
 	EnvNoSync       = "REDO_NO_SYNC"
 
-	RedoDir    = ".redo"
-	LockSuffix = ".lock"
-	DepSuffix  = ".rec"
-	TmpPrefix  = ".redo."
-	LogSuffix  = ".log"
+	RedoDir      = ".redo"
+	LockSuffix   = ".lock"
+	DepSuffix    = ".rec"
+	TmpPrefix    = ".redo."
+	LogSuffix    = ".log"
+	LogRecSuffix = ".log-rec"
 )
 
 var (
@@ -384,14 +385,13 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 	if StderrKeep {
 		fdStderr, err = os.OpenFile(
 			path.Join(redoDir, tgt+LogSuffix),
-			os.O_WRONLY|os.O_CREATE,
+			os.O_WRONLY|os.O_CREATE|os.O_TRUNC,
 			os.FileMode(0666),
 		)
 		if err != nil {
 			cleanup()
 			return TgtErr{tgtOrig, err}
 		}
-		fdStderr.Truncate(0)
 	}
 	shCtx := fmt.Sprintf(
 		"sh: %s: %s %s cwd:%s dirprefix:%s",
@@ -448,13 +448,12 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 			fdStdout.Close()
 			if fdStderr != nil {
 				fdStderr.Close()
-				logRecPath := path.Join(redoDir, tgt+LogSuffix+DepSuffix)
+				logRecPath := path.Join(redoDir, tgt+LogRecSuffix)
 				if fdStderr, err = os.OpenFile(
 					logRecPath,
-					os.O_WRONLY|os.O_CREATE,
+					os.O_WRONLY|os.O_CREATE|os.O_TRUNC,
 					os.FileMode(0666),
 				); err == nil {
-					fdStderr.Truncate(0)
 					fields := []recfile.Field{
 						{Name: "Build", Value: BuildUUID},
 						{Name: "PID", Value: strconv.Itoa(cmd.Process.Pid)},
